MyApp class

Inheritance
Available extensions

Properties

appBuilder Widget Function(BuildContext, Widget?)?
final
appName String?
final
backInfoText String
final
designSize Size
final
draggable bool
final
dragToMoveArea bool
final
enableDoubleClickFullScreen bool
final
exitGapTime Duration
final
exitInfoText String
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyToRollBack LogicalKeyboardKey?
final
marginZero Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
paddingZero Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
pageTransitionDuration Duration
final
pageTransitionStyle Transition
final
routes List<MyRoute<GetxController>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
services List<MyService>?
final
showDebugTag bool
final
sliverBox Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
splash MySplash?
final
theme ThemeData?
final
useToast bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

setFocus({String? focusKey, VoidCallback? onPressed, bool opacity = false, Color focusedBorderColor = Colors.grey, double borderWidth = 1.5, Duration animationDuration = const Duration(milliseconds: 350), double opacityBeginScale = 0.65}) Widget

Available on Widget, provided by the XlyFocusableExtension extension

showRightMenu({required BuildContext context, required List<MyMenuElement> menuElements, MyMenuPopStyle animationStyle = MyMenuPopStyle.scale, MyMenuStyle? style}) Widget

Available on Widget, provided by the RightClickMenuExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isSplashFinished RxBool
final

Static Methods

collapseDockedWindow() Future<void>
手动收缩窗口到停靠位置
disableEdgeDocking() → void
禁用窗口边缘停靠功能
dockToCorner(WindowCorner corner) Future<bool>
停靠窗口到指定角落(简单对齐,不隐藏)
enableCornerDocking({required WindowCorner corner, double visibleSize = 20.0, int hoverDelay = 300}) Future<bool>
启用角落停靠功能(类似QQ的角落停靠行为)
enableEdgeDocking({required WindowEdge edge, double visibleWidth = 5.0, int hoverDelay = 300}) Future<bool>
启用窗口边缘停靠功能(类似QQ的停靠行为)
enableSimpleEdgeDocking({required WindowEdge edge, double visibleWidth = 5.0}) Future<bool>
简化版边缘停靠功能(基于窗口焦点事件)
exit() Future<void>
静态方法用于退出应用
expandDockedWindow() Future<void>
手动展开停靠的窗口
getWindowTitle() String
initialize({required Size designSize, required List<MyRoute<GetxController>> routes, String? appName, List<MyService>? services, MyTray? tray, MyFloatPanel? floatPanel, MySplash? splash, Transition pageTransitionStyle = Transition.fade, Duration pageTransitionDuration = const Duration(milliseconds: 300), Widget appBuilder(BuildContext, Widget?)?, Size? minimumSize, bool centerWindowOnInit = true, bool showWindowOnInit = true, bool focusWindowOnInit = true, bool draggable = true, bool resizable = true, bool doubleClickToFullScreen = false, bool setTitleBarHidden = true, bool setWindowButtonVisibility = false, bool setSkipTaskbar = false, bool setMaximizable = true, bool setAspectRatio = true, bool setAspectRatioEnabled = true, ThemeData? theme, bool showDebugTag = true, bool dragToMoveArea = true, LogicalKeyboardKey? keyToRollBack, String exitInfoText = '再按一次退出App', String backInfoText = '再按一次返回上一页', Duration exitGapTime = const Duration(seconds: 2), bool useOKToast = true, bool enableDebugLogging = false, bool singleInstance = true, String? singleInstanceKey, bool singleInstanceActivateOnSecond = true, bool ensureScreenSize = true, bool initializeWidgetsBinding = true, bool initializeWindowManager = true, bool initializeGetStorage = true, bool installErrorHandlers = true, void onError(Object error, StackTrace stack)?, bool enableZoneGuard = false}) Future<void>
isAspectRatioEnabled() bool
获取当前窗口比例调整功能的状态
isDoubleClickMaximizeEnabled() bool
获取当前双击最大化功能的状态 在智能停靠状态下自动禁用双击最大化功能
isDraggableEnabled() bool
获取当前窗口拖动功能的状态
isFullScreenEnabled() bool
获取当前全屏功能的状态 在智能停靠状态下自动禁用全屏功能
isResizableEnabled() bool
获取当前窗口大小调整功能的状态
isSmartDockingEnabled() bool
获取智能边缘停靠的启用状态
isTitleBarHidden() bool
获取当前标题栏的隐藏状态
setAspectRatioEnabled(bool enabled) Future<void>
设置窗口比例调整功能的启用状态
setDoubleClickMaximizeEnabled(bool enabled) Future<void>
设置双击最大化功能的启用状态
setDraggableEnabled(bool enabled) Future<void>
设置窗口拖动功能的启用状态
setFullScreenEnabled(bool enabled) Future<void>
设置全屏功能的启用状态
setResizableEnabled(bool enabled) Future<void>
设置窗口大小调整功能的启用状态
setSmartEdgeDocking({required bool enabled, double visibleWidth = 5.0}) Future<void>
启用/禁用智能停靠机制(类似QQ的智能停靠功能)
setTitleBarHidden(bool hidden) Future<void>
设置标题栏的显示/隐藏状态
setWindowTitle(String title) Future<void>
Window Title APIs
toggleDockedWindow() Future<void>
切换停靠窗口的展开/收缩状态
toggleFullScreen() Future<void>
切换全屏状态 在智能停靠状态下此方法无效