MyBootstrapSeverity enum

MyApp.initialize bootstrap 项的失败等级。未分级时按 degraded

Inheritance
Available extensions

Values

fatal → const MyBootstrapSeverity

没有它不能装成已启动:叠层停在错误态,不揭开首页。

degraded → const MyBootstrapSeverity

壳能出,但缺一块能力:按公式揭开,首页须能表达缺失。

optional → const MyBootstrapSeverity

增强项:失败只打日志,不影响门闩。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MyBootstrapSeverity>
A constant List of the values in this enum, in order of their declaration.