MyRoute<T extends GetxController> class

Constructors

MyRoute({required String path, required Widget page, required T controller()})

Properties

controller → T Function()
final
hashCode int
The hash code for this object.
no setterinherited
page Widget
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerController() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited