MySplashPhase enum

启动叠层门闩阶段。

Inheritance
Available extensions

Values

running → const MySplashPhase

正在跑 blocking bootstrap,或还在等品牌一圈 / 静态脸 MySplash.minVisible

ready → const MySplashPhase

blocking 项全部成功。

degraded → const MySplashPhase

仅 degraded / optional 失败,或 bootstrap 超时且无未决 fatal。

fatal → const MySplashPhase

有 fatal 失败:叠层留错误态。

finished → const MySplashPhase

已按公式揭开(或无叠层)。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MySplashPhase>
A constant List of the values in this enum, in order of their declaration.