DisabledStyle class
禁用样式配置
Constructors
- DisabledStyle.custom(Widget builder(double iconSize))
-
const
- DisabledStyle.defaultX()
-
const
- DisabledStyle.dimOnly()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- overlayBuilder → Widget Function(double iconSize)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DisabledStyleType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited