HorizontalExpandMode enum
上下停靠时的展开方向
Values
- none → const HorizontalExpandMode
-
不横向展开,保持竖向展开
- leftToRight → const HorizontalExpandMode
-
从左到右展开(handle 在左端,默认)
- rightToLeft → const HorizontalExpandMode
-
从右到左展开(handle 在右端)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HorizontalExpandMode> - A constant List of the values in this enum, in order of their declaration.