MyFloatBoxController class

Inheritance

Constructors

MyFloatBoxController()

Properties

backgroundColor Color
no setter
borderColor Color
no setter
currentBorderRadius Rx<BorderRadius>
final
currentBorderWidth RxDouble
final
currentDockOffset RxDouble
final
currentIconSize RxDouble
final
currentPanelOpenOffset RxDouble
final
currentPanelWidth RxDouble
final
customButtonColor Color
no setter
customButtonFocusColor Color
no setter
dockAnimCurve Curve
no setter
dockAnimDuration int
no setter
dockType DockType
no setter
effectiveBorderRadius BorderRadius
no setter
effectivePanelBorder Border?
no setter
effectivePanelHeight double
no setter
effectivePanelWidth double
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
initialPanelIcon IconData
no setter
innerButtonFocusColor Color
no setter
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isFocusColors RxList<bool>
final
items List<MyFloatPanelIconBtn>
no setter
listeners int
no setterinherited
movementSpeed RxInt
final
onDelete InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
panelAnimCurve Curve
no setter
panelAnimDuration int
no setter
panelButtonColor Color
no setter
panelIcon Rx<IconData>
final
panelShape PanelShape
no setter
panelState Rx<PanelState>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xOffset RxDouble
final
yOffset RxDouble
final

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onInnerButtonTap() → void
onPanEndGesture() → void
onPanStartGesture(Offset globalPosition) → void
onPanUpdateGesture(Offset globalPosition) → void
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
setButtonFocus(int index, bool focused) → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateScaledDimensions({required double scaledPanelWidth, required double scaledBorderWidth, required double scaledIconSize, required BorderRadius scaledBorderRadius, required double scaledPanelOpenOffset, required double scaledDockOffset}) → void
更新缩放后的尺寸值(由 UI 层调用)
updateScreenSize(double pWidth, double pHeight) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited