MyFloatPanel class

全局浮动面板管理器(类似 MyTray.to)

Inheritance

Constructors

MyFloatPanel()

Properties

backgroundColor Rx<Color>
final
borderColor Rx<Color>
final
borderRadius Rx<BorderRadius>
final
customButtonColor Rx<Color>
final
disabledIds RxSet<String>
final
disabledIdsRx RxSet<String>
no setter
disabledStyle Rx<DisabledStyle>
final
dockActivate RxBool
final
dockAnimCurve Rx<Curve>
final
dockAnimDuration RxInt
final
dockToAllEdges RxBool
final
dockType Rx<DockType>
final
enablePersistence RxBool
final
focusColor Rx<Color>
final
handleFocusColor Rx<Color>
final
hashCode int
The hash code for this object.
no setterinherited
highlightedIds RxSet<String>
final
highlightedIdsRx RxSet<String>
no setter
horizontalExpandMode Rx<HorizontalExpandMode>
final
iconBtns MyFloatPanelIconBtnsCtrl
no setter
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
initialPanelIcon Rx<IconData>
final
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
items RxList<MyFloatPanelIconBtn>
final
onDelete InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
panelAnimCurve Rx<Curve>
final
panelAnimDuration RxInt
final
panelButtonColor Rx<Color>
final
panelShape Rx<PanelShape>
final
panelWidth RxDouble
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible RxBool
final

Methods

$configureLifeCycle() → void
inherited
buildOverlay() Widget
MyApp 挂载的全局浮动条 overlay(样式从 MyFloatPanel.to 实时读取)。
configure({List<MyFloatPanelIconBtn>? items, bool? visible, bool? enablePersistence, bool? dockToAllEdges, HorizontalExpandMode? horizontalExpandMode, Color? borderColor, IconData? initialPanelIcon, int? panelAnimDuration, Curve? panelAnimCurve, int? dockAnimDuration, Curve? dockAnimCurve}) → void
hide() → void
iconBtn(String id) MyFloatPanelIconBtnCtrl
isDisabled(String id) bool
isHighlighted(String id) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
resetToDefault() → void
恢复到首次 configure() 时的默认配置
show() → void
toggle() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

to MyFloatPanel
no setter