MyFloatPanelIconBtnCtrl class

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
isEnabled bool
no setter
isHighlighted bool
whether current id is highlighted
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEnabled(bool value) MyFloatPanelIconBtnCtrl
setHighlighted(bool value) MyFloatPanelIconBtnCtrl
设置该 id 的“常亮(高亮显示)”状态;不影响启用/禁用
toggleEnabled() MyFloatPanelIconBtnCtrl
toggleHighlighted() MyFloatPanelIconBtnCtrl
toggle highlighted state
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited