MySelectorClearOption class

选择器列表顶部"清除"入口的配置。

传给 MySelector.showclearOption 参数;为 null 时不显示清除项。

clearOption: MySelectorClearOption(label: '不选择'),
clearOption: MySelectorClearOption(
  label: '不限国家',
  leading: Icon(Icons.public_off, size: 14),
  subtitle: '显示所有地区内容',
),

Constructors

MySelectorClearOption({String label = '清除', Widget? leading, String? subtitle})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
清除项的显示文字,如"不选择"、"清除"、"全部"。
final
leading Widget?
可选前缀组件(图标、色块等),为 null 时显示默认的 cancel_outlined 图标。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
可选副标题说明文字。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited