MySelectorItem<T> class
选择器列表项
泛型 T 为选中后返回的值类型,需要正确实现 == 运算符。
Constructors
Properties
-
badges
→ List<
Widget> ? -
标题右侧的小徽章列表(能力图标等)
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leading → Widget?
-
左侧自定义组件(图标、头像、色块等)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
final
- title → String
-
final
- value → T
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited