MySelectorValueChanged<T> class final

用户做出了明确操作:

  • valuenull:主动清除选中(通过清除项或复选取消),此时 item 也为 null
  • valuenull:选中了具体某项,item 为对应的完整列表项
Inheritance
Available extensions

Constructors

MySelectorValueChanged(T? value, {MySelectorItem<T>? item})
const

Properties

changed MySelectorValueChanged<T>?

Available on MySelectorResult<T>, provided by the MySelectorResultX extension

用户做出了明确操作时返回 MySelectorValueChanged,否则返回 null
no setter
hashCode int
The hash code for this object.
no setterinherited
isDismissed bool

Available on MySelectorResult<T>, provided by the MySelectorResultX extension

用户是否点击了外部/按 Escape 关闭面板(未做出明确选择)。
no setter
item MySelectorItem<T>?
选中的完整列表项;清除操作时为 null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited