MySmartDock class

智能停靠管理器

重构后的智能停靠管理器,作为各个组件的协调器:

  • 使用 DockDetector 进行停靠检测
  • 使用 WindowAnimator 处理动画
  • 使用 MouseTracker 处理鼠标跟踪
  • 使用 WindowFocusManager 处理焦点管理

Constructors

MySmartDock()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isSmartDockingEnabled() bool
获取智能停靠启用状态
setSmartEdgeDocking({required bool enabled, double visibleWidth = 5.0}) Future<void>
启用/禁用智能停靠机制
stopAll() Future<void>
停止所有智能停靠功能