MyTextEditorController class
Methods
-
$configureLifeCycle()
→ void
-
inherited
-
addListener(GetStateUpdate listener)
→ Disposer
-
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(Object? key, GetStateUpdate listener)
→ Disposer
-
inherited
-
clearHighlight()
→ void
-
Clear highlight
-
dispose()
→ void
-
inherited
-
disposeId(Object id)
→ void
-
To dispose an
id from future updates(), this ids are registered
by GetBuilder() or similar, so is a way to unlink the state change with
the Widget from the Controller.
inherited
-
markDropdownManuallyClosed()
→ void
-
Mark that user manually closed the dropdown
-
markJustSelected()
→ void
-
Mark that an option was just selected
-
navigateDown()
→ void
-
Navigate to next option
-
navigateUp()
→ void
-
Navigate to previous option
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyChildrens()
→ void
-
inherited
-
onClose()
→ void
-
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
override
-
onInit()
→ void
-
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
override
-
onReady()
→ void
-
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
refresh()
→ void
-
inherited
-
refreshGroup(Object id)
→ void
-
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(Object id, VoidCallback listener)
→ void
-
inherited
-
resetManuallyClosedFlag()
→ void
-
Reset the manually closed flag (when user starts typing or focuses)
-
selectHighlighted()
→ String?
-
Select current highlighted option
-
setDropdownOpen(bool open)
→ void
-
-
setDropdownParameters({required double itemHeight})
→ void
-
Set dropdown parameters for scroll calculation
-
setDropdownScrollController(ScrollController? controller)
→ void
-
Set dropdown scroll controller
-
setFocus(String key)
→ void
-
-
setHighlightedOption(String? option)
→ void
-
-
setOptionsDirection(OptionsViewOpenDirection dir)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
update([List<Object>? ids, bool condition = true])
→ void
-
Rebuilds
GetBuilder each time you call update();
Can take a List of ids, that will only update the matching
GetBuilder( id: ),
ids can be reused among GetBuilders like group tags.
The update will only notify the Widgets, if condition is true.
inherited
-
updateCurrentOptions(List<String> options)
→ void
-
Update current options for keyboard navigation
-
updateHasText(String text)
→ void
-