MyNotifyFallbackPolicy enum

系统通知被平台策略静默时的应用内兜底策略。

Inheritance
Available extensions

Values

never → const MyNotifyFallbackPolicy

不显示应用内兜底提示。

windowsOnly → const MyNotifyFallbackPolicy

仅 Windows 平台显示应用内兜底提示。

always → const MyNotifyFallbackPolicy

所有平台都显示应用内兜底提示。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MyNotifyFallbackPolicy>
A constant List of the values in this enum, in order of their declaration.