MyNotifyWindowsFocusAssistMode enum

Windows 专注助手 / 勿扰模式状态。

Inheritance
Available extensions

Values

unavailable → const MyNotifyWindowsFocusAssistMode

当前平台不支持该诊断。

unknown → const MyNotifyWindowsFocusAssistMode

当前系统未能返回可识别状态。

off → const MyNotifyWindowsFocusAssistMode

关闭,普通通知可以弹出横幅。

priorityOnly → const MyNotifyWindowsFocusAssistMode

仅优先通知,普通通知通常会直接进入操作中心。

alarmsOnly → const MyNotifyWindowsFocusAssistMode

仅限闹钟,普通通知不会弹出横幅。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MyNotifyWindowsFocusAssistMode>
A constant List of the values in this enum, in order of their declaration.