MyUserDataDirValidation class

用户数据目录校验结果(用于启用/禁用「确定」与提示文案)。

Constructors

MyUserDataDirValidation({required bool canConfirm, String? hint})
const

Properties

canConfirm bool
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited