MySplashGate class

启动叠层门闩:首帧提交后跑 MyBootstrapTask,按公式揭开 MySplash

一般由 MyApp.initialize 创建。测试可直接构造。

Constructors

MySplashGate({required bool hasOverlay, required bool hasBrandLottie, required bool hasStaticBrandFace, Duration minVisible = const Duration(milliseconds: 300), Duration brandTimeout = const Duration(seconds: 8), Duration bootstrapTimeout = const Duration(seconds: 20), List<MyBootstrapTask>? tasks, VoidCallback? onVisible, bool showWindowAfterFirstFrame = false, bool focusWindowAfterFirstFrame = false, void onError(Object error, StackTrace stack)?})

Properties

bootstrapTimeout Duration
final
brandTimeout Duration
final
canDismiss bool
no setter
fatalMessage String?
no setter
focusWindowAfterFirstFrame bool
final
hasBrandLottie bool
final
hashCode int
The hash code for this object.
no setterinherited
hasOverlay bool
final
hasStaticBrandFace bool
final
isFinished bool
no setter
minVisible Duration
final
onError → void Function(Object error, StackTrace stack)?
final
onVisible VoidCallback?
final
phase MySplashPhase
no setter
ready Future<void>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showWindowAfterFirstFrame bool
final
tasks List<MyBootstrapTask>
final

Methods

attachToApp() → void
绑定为当前 MyApp 门闩,并按有无叠层重置静态量。
debugOnFirstFrameSubmitted() Future<void>
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportAnimationDone() → void
startAfterFirstFrame() Future<void>
runApp 之后调用,不要 await 它,以免挡住 initialize 返回。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited