MySelectorDismissed<T> class
final
用户关闭了面板但没有做出明确选择(点击外部区域或按 Escape)。
- Inheritance
-
- Object
- MySelectorResult<
T> - MySelectorDismissed
- Available extensions
Constructors
- MySelectorDismissed()
-
const
Properties
-
changed
→ MySelectorValueChanged<
T> ? -
Available on MySelectorResult<
用户做出了明确操作时返回 MySelectorValueChanged,否则返回T> , provided by the MySelectorResultX extensionnull。no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isDismissed → bool
-
Available on MySelectorResult<
用户是否点击了外部/按 Escape 关闭面板(未做出明确选择)。T> , provided by the MySelectorResultX extensionno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited