MySelectorStyle class

选择器样式配置

panelWidth 外,传入的数值为设计稿尺寸(基于 ScreenUtil 初始化的设计稿宽度), 构造时自动通过 .h / .r 转换。panelWidth 表示调用方已经换算后的固定宽度, 不再内部 .w

Constructors

MySelectorStyle({double maxHeight = 360, double? panelWidth, double borderRadius = 14, double blurSigma = 28, Color selectedColor = const Color(0xFF4F6BFE), double shadowOpacity = 0.12, Color hoverColor = defaultHoverColor})

Properties

blurSigma double
final
borderRadius double
final
hashCode int
The hash code for this object.
no setterinherited
hoverColor Color
悬停背景色。
final
maxHeight double
final
panelWidth double?
面板宽度。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color
final
shadowOpacity double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHoverColor → const Color
默认悬停色:黑色 6% 透明叠加,适配浅色背景面板。