MySelectorValueChanged<T> class
final
- Inheritance
-
- Object
- MySelectorResult<
T> - MySelectorValueChanged
- Available extensions
Constructors
-
MySelectorValueChanged(T? value, {MySelectorItem<
T> ? item}) -
const
Properties
-
changed
→ MySelectorValueChanged<
T> ? -
Available on MySelectorResult<
用户做出了明确操作时返回 MySelectorValueChanged,否则返回T> , provided by the MySelectorResultX extensionnull。no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isDismissed → bool
-
Available on MySelectorResult<
用户是否点击了外部/按 Escape 关闭面板(未做出明确选择)。T> , provided by the MySelectorResultX extensionno setter -
item
→ MySelectorItem<
T> ? -
选中的完整列表项;清除操作时为
null。final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited