MyDialog class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
show({required Widget content, FutureOr<void> onLeftButtonPressed()?, FutureOr<void> onRightButtonPressed()?, String title = '提示', String leftButtonText = '取消', String rightButtonText = '确定', Color? backgroundColor, Color? titleColor, Color? leftButtonColor = Colors.black54, Color? rightButtonColor = Colors.blue, double? borderRadius, double? elevation, double? barrierOpacity, bool barrierDismissible = true, MyModalAttentionEffect barrierAttentionEffect = MyModalAttentionEffect.shake})
→ Future<MyDialogChosen>
-
显示 Material 风格对话框。
-
showIos({required Widget content, FutureOr<void> onLeftButtonPressed()?, FutureOr<void> onRightButtonPressed()?, String title = '提示', String leftButtonText = '取消', String rightButtonText = '确定', Color? backgroundColor, Color? titleColor, Color? leftButtonColor = CupertinoColors.systemGrey, Color? rightButtonColor = CupertinoColors.systemBlue, double? borderRadius, double? elevation, double? barrierOpacity, bool barrierDismissible = true, MyModalAttentionEffect barrierAttentionEffect = MyModalAttentionEffect.shake})
→ Future<MyDialogChosen>
-