MyUserDataDirBootstrapResult class
启动前解析用户数据目录的结果。
Constructors
- MyUserDataDirBootstrapResult({required bool needsDesktopSetup, String? loadedPath, String? storedPath, MyUserDataDirValidation? storedEvaluation})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasInvalidStoredPath → bool
-
Store 有记录但目录不可用(不存在或不可写等)。
no setter
- loadedPath → String?
-
prepare已成功 MyPaths.setUserDataDir 时的路径。final - needsDesktopSetup → bool
-
桌面端需在 UI 中让用户选择数据目录。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storedEvaluation → MyUserDataDirValidation?
-
对 storedPath 的 MyUserDataDirValidator.evaluate 结果;无 stored 时为 null。
final
- storedPath → String?
-
MyUserDataDirStore.load 的原始值(不论是否已通过校验)。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited